@@ -4,7 +4,7 @@ use warnings;
 
 package Path::Class::Rule;
 # ABSTRACT: File finder using Path::Class
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 # Dependencies
 use namespace::autoclean;
@@ -30,7 +30,7 @@ sub clone {
 }
 
 sub add_helper {
-  my ($class, $name, $coderef) = @_;
+  my ($class, $name, $coderef, $skip_negation) = @_;
   $class = ref $class || $class;
   if ( ! $class->can($name) ) {
     no strict 'refs'; ## no critic
@@ -39,11 +39,13 @@ sub add_helper {
       my $rule = $coderef->(@_);
       $self->and( $rule )
     };
-    *{"not_$name"} = sub {
-      my $self = shift;
-      my $rule = $coderef->(@_);
-      $self->not( $rule )
-    };
+    if ( ! $skip_negation ) {
+      *{"not_$name"} = sub {
+        my $self = shift;
+        my $rule = $coderef->(@_);
+        $self->not( $rule )
+      };
+    }
   }
   else {
     Carp::carp(
@@ -227,15 +229,6 @@ my %complex_helpers = (
       return (first { $name =~ $_} @patterns ) ? 1 : 0;
     }
   },
-  skip_dirs => sub {
-    Carp::croak("No patterns provided to 'skip_dirs'") unless @_;
-    my $name_check = Path::Class::Rule->new->name(@_);
-    return sub {
-      my $f = shift;
-      return "0 but true" if $f->is_dir && $name_check->test($f);
-      return 1; # otherwise, like a null rule
-    }
-  },
   min_depth => sub {
     Carp::croak("No depth argument given to 'min_depth'") unless @_;
     my $min_depth = 0 + shift; # if this warns, do here and not on every file
@@ -252,12 +245,37 @@ my %complex_helpers = (
       return $stash->{_depth} <= $max_depth ? 1 : "0 but true"; # prune
     }
   },
+  shebang => sub {
+    Carp::croak("No patterns provided to 'shebang'") unless @_;
+    my @patterns = map { _regexify($_) } @_;
+    return sub {
+      my $f = shift;
+      return unless ! $f->is_dir;
+      my $fh = $f->open;
+      my $shebang = <$fh>;
+      return unless defined $shebang;
+      return (first { $shebang =~ $_} @patterns ) ? 1 : 0;
+    };
+  },
 );
 
 while ( my ($k,$v) = each %complex_helpers ) {
   __PACKAGE__->add_helper( $k, $v );
 }
 
+# skip_dirs
+__PACKAGE__->add_helper(
+  skip_dirs => sub {
+    Carp::croak("No patterns provided to 'skip_dirs'") unless @_;
+    my $name_check = Path::Class::Rule->new->name(@_);
+    return sub {
+      my $f = shift;
+      return "0 but true" if $f->is_dir && $name_check->test($f);
+      return 1; # otherwise, like a null rule
+    }
+  } => 1 # don't create not_skip_dirs
+);
+
 # X_tests adapted from File::Find::Rule
 my %X_tests = (
     -r  =>  readable           =>  -R  =>  r_readable      =>
@@ -313,6 +331,70 @@ for my $name ( @stat_tests ) {
   __PACKAGE__->add_helper( $name, $coderef );
 }
 
+# VCS rules adapted from File::Find::Rule::VCS
+my %vcs_rules = (
+  skip_cvs => sub {
+    return Path::Class::Rule->new->skip_dirs('CVS')->not_name(qr/\.\#$/);
+  },
+  skip_rcs => sub {
+    return Path::Class::Rule->new->skip_dirs('RCS')->not_name(qr/,v$/);
+  },
+  skip_git => sub {
+    return Path::Class::Rule->new->skip_dirs('.git');
+  },
+  skip_svn => sub {
+    return Path::Class::Rule->new->skip_dirs(
+        ($^O eq 'MSWin32') ? ('.svn', '_svn') : ('.svn')
+    );
+  },
+  skip_bzr => sub {
+    return Path::Class::Rule->new->skip_dirs('.bzr');
+  },
+  skip_hg => sub {
+    return Path::Class::Rule->new->skip_dirs('.hg');
+  },
+  skip_vcs => sub {
+    return Path::Class::Rule->new
+      ->skip_dirs(qw/.git .bzr .hg CVS RCS/)
+      ->skip_svn
+      ->not_name(qr/\.\#$/, qr/,v$/);
+  },
+);
+
+while ( my ($name, $coderef) = each %vcs_rules ) {
+  __PACKAGE__->add_helper( $name, $coderef, 1 ); # don't create not_*
+}
+
+
+# perl rules adapted from File::Find::Rule::Perl
+my %perl_rules = (
+  perl_module     => sub { return Path::Class::Rule->new->file->name('*.pm') },
+  perl_pod        => sub { return Path::Class::Rule->new->file->name('*.pod') },
+  perl_test       => sub { return Path::Class::Rule->new->file->name('*.t') },
+  perl_installer  => sub {
+    return Path::Class::Rule->new->file->name('Makefile.PL', 'Build.PL')
+  },
+  perl_script     => sub {
+    return Path::Class::Rule->new->file->or(
+      Path::Class::Rule->new->name('*.pl'),
+      Path::Class::Rule->new->shebang(qr/#!.*\bperl\b/),
+    );
+  },
+  perl_file       => sub {
+    return Path::Class::Rule->new->or(
+      Path::Class::Rule->new->perl_module,
+      Path::Class::Rule->new->perl_pod,
+      Path::Class::Rule->new->perl_test,
+      Path::Class::Rule->new->perl_installer,
+      Path::Class::Rule->new->perl_script,
+    );
+  },
+);
+
+while ( my ($name, $coderef) = each %perl_rules ) {
+  __PACKAGE__->add_helper( $name, $coderef );
+}
+
 1;
 
 
@@ -327,7 +409,7 @@ Path::Class::Rule - File finder using Path::Class
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -626,6 +708,38 @@ The C<min_depth> and C<max_depth> rule methods take a single argument
 and limit the paths returned to a minimum or maximum depth (respectively)
 from the starting search directory.
 
+=head2 Perl file rules
+
+  # All perl rules
+  $rule->perl_files;
+
+  # Individual perl file rules
+  $rule->perl_module;     # .pm files
+  $rule->perl_pod;        # .pod files 
+  $rule->perl_test;       # .t files
+  $rule->perl_installer;  # Makefile.PL or Build.PL
+  $rule->perl_script;     # .pl or 'perl' in the shebang
+
+These rule methods match file names (or a shebang line) that are typical
+of Perl distribution files.
+
+=head2 Version control file rules
+
+  # Skip all known VCS files
+  $rule->skip_vcs;
+
+  # Skip individual VCS files
+  $rule->skip_cvs;
+  $rule->skip_rcs;
+  $rule->skip_svn;
+  $rule->skip_git;
+  $rule->skip_bzr;
+  $rule->skip_hg;
+
+Skips files and/or prunes directories related to a version control system.
+Just like C<skip_dirs>, these rules should be specified early to get the
+correct behavior.
+
 =head2 Other rules
 
 =head3 C<dangling>
@@ -637,15 +751,25 @@ The C<dangling> rule method matches dangling symlinks.  Use it or its inverse
 to control how dangling symlinks should be treated.  Note that a dangling
 symlink will be returned by the iterator as a L<Path::Class::File> object.
 
+=head3 C<shebang>
+
+  $rule->shebang(qr/#!.*\bperl\b/);
+
+The C<shebang> rule takes a list of regular expressions or glob patterns and
+checks them against the first line of a file.
+
 =head2 Negated rules
 
-All rule methods have a negated form preceded by "not_".
+Most rule methods have a negated form preceded by "not_".
 
   $rule->not_name("foo.*")
 
 Because this happens automatically, it includes somewhat silly ones like
 C<not_nonempty> (which is thus a less efficient way of saying C<empty>).
 
+Rules that skip directories or version control files do not have a negated
+version.
+
 =head1 EXTENDING
 
 =head2 Custom rule subroutines
@@ -707,8 +831,9 @@ One of the strengths of L<File::Find::Rule> is the many CPAN modules
 that extend it.  C<Path::Class::Rule> provides the C<add_helper> method
 to provide a similar mechanism for extensions.
 
-The C<add_helper> class method takes two arguments, a C<name> for the rule
-method and a closure-generating callback.  An inverted "not_*" method is
+The C<add_helper> class method takes three arguments, a C<name> for the rule
+method, a closure-generating callback, and a flag for not generating a negated
+form of the rule.  Unless the flag is true, an inverted "not_*" method is
 generated automatically.  Extension classes should call this as a class method
 to install new rule methods.  For example, this adds a "foo" method that checks
 if the filename is "foo":
@@ -739,8 +864,8 @@ an existing method.
 
 =head1 CAVEATS
 
-This is an early release for community feedback and contribution.  The
-API may still change.  Some features are still unimplemented:
+This is an early release for community feedback and contribution.
+Some features are still unimplemented:
 
 =over 4
 
@@ -762,7 +887,7 @@ Extension class loading via C<import()>
 
 =back
 
-Test coverage is still poor.
+Test coverage is poor.
 
 Filetest operators and stat rules are subject to the usual portability
 considerations.  See L<perlport> for details.
